@@ -43,6 +43,22 @@ class MessageAttachment:
             self.__dict__ = data
 
 
+class MessageEmbedThumbnail:
+    def __init__(self, data=None):
+        # 图片地址
+        self.url: str = ""
+        if data is not None:
+            self.__dict__ = data
+
+
+class MessageEmbedField:
+    def __init__(self, data=None, name: str = None, value: str = None):
+        self.name = name
+        self.value = value
+        if data:
+            self.__dict__ = data
+
+
 class MessageEmbed:
     def __init__(self, data=None):
         # 标题
@@ -57,18 +73,28 @@ class MessageEmbed:
             self.__dict__ = data
 
 
-class MessageEmbedThumbnail:
-    def __init__(self, data=None):
-        # 图片地址
-        self.url: str = ""
-        if data is not None:
+class MessageArkObjKv:
+    def __init__(self, data=None, key: str = None, value: str = None):
+        self.key = key
+        self.value = value
+        if data:
             self.__dict__ = data
 
 
-class MessageEmbedField:
+class MessageArkObj:
     def __init__(self, data=None):
-        self.name: str = ""
-        self.value: str = ""
+        self.obj_kv: List[MessageArkObjKv] = [MessageArkObjKv()]
+        if data:
+            self.__dict__ = data
+
+
+class MessageArkKv:
+    def __init__(
+        self, data=None, key: str = None, value: str = None, obj: MessageArkObj = None
+    ):
+        self.key = key
+        self.value = value
+        self.obj = obj
         if data:
             self.__dict__ = data
 
@@ -81,34 +107,10 @@ class MessageArk:
             self.__dict__ = data
 
 
-class MessageArkKv:
-    def __init__(self, data=None):
-        self.key: str = ""
-        self.value: str = ""
-        self.obj: List[MessageArkObj] = [MessageArkObj()]
-        if data:
-            self.__dict__ = data
-
-
-class MessageArkObj:
-    def __init__(self, data=None):
-        self.obj_kv: List[MessageArkObjKv] = [MessageArkObjKv()]
-        if data:
-            self.__dict__ = data
-
-
-class MessageArkObjKv:
-    def __init__(self, data=None):
-        self.key: str = ""
-        self.value: str = ""
-        if data:
-            self.__dict__ = data
-
-
 class MessageSendRequest:
     def __init__(
         self,
-        content: str,
+        content: str = "",
         msg_id: str = None,
         embed: MessageEmbed = None,
         ark: MessageArk = None,
